@@ -116,7 +116,7 @@ ggplot_stars <- function(data,
                          coastline_pal = "black",
                          title = "[Title]",
                          subtitle = NULL,
-                         caption = "",
+                         caption = NULL,
                          font_family = "Helvetica",
                          font_size_title = NULL,
                          font_size_body = NULL,
@@ -252,7 +252,7 @@ ggplot_stars_col <- function(data,
                              title = "[Title]",
                              subtitle = NULL,
                              col_title = "",
-                             caption = "",
+                             caption = NULL,
                              legend_labels = NULL,
                              font_family = "Helvetica",
                              font_size_title = NULL,
@@ -454,7 +454,7 @@ ggplot_stars_facet <- function(data,
                                facet_nrow = NULL,
                                title = "[Title]",
                                subtitle = NULL,
-                               caption = "",
+                               caption = NULL,
                                font_family = "Helvetica",
                                font_size_title = NULL,
                                font_size_body = NULL,
@@ -624,7 +624,7 @@ ggplot_stars_col_facet <- function(data,
                                    title = "[Title]",
                                    subtitle = NULL,
                                    col_title = "",
-                                   caption = "",
+                                   caption = NULL,
                                    legend_labels = NULL,
                                    font_family = "Helvetica",
                                    font_size_title = NULL,
